/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none

Files needed: 

mw_state_annual_march12.dta - Annual March 12th state MW data

population_state_annual.dta - Annual state population

gsp_state_annual.dta - Annual gross state product

unemprt_state_annual.dta - Annualized state unemployment rates

BDS:   bds_e_st_release.csv - from Census Bureau - http://www2.census.gov/ces/bds/estab/bds_e_st_release.csv

NOTE: See the DataSources.txt file for more information


*/

*--------------------*
*        BDS         *
*--------------------*

insheet using bds_e_st_release.csv , clear

rename year2 year
rename state statefips
rename job_creation jc
rename job_destruction jd

gen lemp = ln(emp)
gen jgr = net_job_creation_rate / 100
gen ljc=ln(jc)
gen ljd=ln(jd)

keep statefips year emp lemp jgr jc jd ljc ljd

order statefips year emp lemp jgr jc ljc jd ljd

label variable statefips "State (FIPS code)"
label variable year "Year"
label variable emp "Employment (levels)"
label variable jc "Jobs created (levels)"
label variable jd "Jobs destroyed (levels)"
label variable jgr "Job growth rate"
label variable lemp "Log of employment"
label variable ljc "Log of jobs created"
label variable ljd "Log of jobs destroyed"

merge 1:1 statefips year using mw_state_annual_march12

/* Adjust minimum wage to that of the prior year. The reason for this adjustment is that
   the BDS reports annual employment values for metrics ending on March 12 of the listed year
   and the minimum wage as of March 12 the previous year is that which was actually in effect.  */

sort statefips year

quietly foreach var in lnmin realmw mw realfedmw fedmw indexedwage {
gen temp = `var'[_n-1] if year >= 1977 & year <= 2011
replace `var' = temp
drop temp
}

label variable mw "State minimum wage value as of previous March 12"
label variable fedmw "Federal minimum wage value as of previous March 12"
label variable realmw "State real minimum wage as of previous March 12 (dollars 2011)"
label variable realfedmw "Federal real minimum wage as of previous March 12 (dollars 2011)"
label variable lnmin "Log of state real minimum wage as of previous March 12 (dollars 2011)"

drop if year < 1977 | year > 2011

drop _merge

merge 1:1 statefips year using population_state_annual
keep if _merge == 3
drop _merge

merge 1:1 statefips year using gsp_state_annual
keep if _merge == 3
drop _merge

merge 1:m statefips year using unemprt_state_annual
keep if _merge == 3
drop _merge

sort state year
xtset state year

order statefips censusreg censusdiv year emp lemp jgr jc ljc jd ljd ///
lnmin realmw mw realfedmw fedmw indexedwage eversuperfed popall lpopall ///
share1559 gsp rgsp rgspcap lrgspcap unemprt unem laborforce

label values statefips fips
label values censusreg census4
label values censusdiv census9

compress
save bds , replace
