/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none
Do-files called: none
Files needed: none

*/

* These are all fake data in fictional examples used as illustration.

*-------------------------*
* EFFECT ON GROWTH RATE   *
*-------------------------*

clear all
set more off

* Set values:
************************************
local precount = 6 // number of 'pre' periods
local postcount = 5 // number of 'post' periods
local baseline = 0.02 // baseline growth rate
local treatpost = `baseline' * 0.75 // treatment on treated growth rate
************************************

local periods = `precount' + `postcount'
set obs `periods'
gen period = _n - `precount'
gen post = (period >= 1)
gen n=_n-1


gen control = 0 + `baseline'*n // for simplicity, intercept for control at zero
gen treat = 0.03 + `baseline'*n // intercept for treated state at 0.1

tsset period

replace treat = treat - (`baseline'-`treatpost')*period if period >=1

reg treat period
predict fittreat

gen diff_tc = treat-control

gen diff_detrend = treat - fittreat // The control detrended is always zero by construction

egen prediff = mean(diff_tc) , by(post)
gen postdiff = prediff if period>0
replace prediff=. if period>0

egen dt_prediff = mean(diff_detrend) , by(post)
gen dt_postdiff = dt_prediff if period>0
replace dt_prediff=. if period>0

gen diff_growth = round(diff_tc - l.diff_tc , 0.000001)
replace diff_growth = f.diff_growth if _n == 1

gen diff_dt_growth = round(diff_detrend - l.diff_detrend, 0.000001)
replace diff_dt_growth = f.diff_dt_growth if _n == 1

egen prediff_growth = mean(diff_growth) , by(post)
gen postdiff_growth = prediff_growth if period > 0
replace prediff_growth = . if period > 0

egen prediff_dt_growth = mean(diff_dt_growth) , by(post)
gen postdiff_dt_growth = prediff_dt_growth if period > 0
replace prediff_dt_growth = . if period > 0

local plusone = _N+1
set obs `plusone'
replace period = 0.5 in `plusone'
sort period

replace prediff=prediff[_n-1] if period ==0.5
replace postdiff=postdiff[_n+1] if period ==0.5
replace dt_prediff=dt_prediff[_n-1] if period ==0.5
replace dt_postdiff=dt_postdiff[_n+1] if period ==0.5

replace prediff_growth = prediff_growth[_n-1] if period ==0.5
replace postdiff_growth = postdiff_growth[_n+1] if period ==0.5
replace prediff_dt_growth = prediff_dt_growth[_n-1] if period ==0.5
replace postdiff_dt_growth = postdiff_dt_growth[_n+1] if period ==0.5

****
* graphs

#delimit ;

tsline treat , lcolor(black) || tsline control , lcolor(gs12) ||
tsline fittreat , lcolor(black) lpattern(dot)
xline(0,lcolor(gs2)) ylabel(0(0.05)0.2)  xtitle("Time") 
ytitle("Employment level", axis(1) margin(r+2.0) )
xlabel(-5(1)5)
legend(rows(1) order(1 "Treated" 2 "Control" 3 "Treated time trend   ")) 
graphregion(color(white))
;
graph export Fig-toy_example_with_fit.png , replace width(1000) ;

graph twoway bar diff_tc period , barwidth(0.25) bcolor(gs12) xtitle("Time" , size(large))
ylabel(-0.01(0.01)0.04) xline(0.5,lcolor(gs2)) xlabel(-5(1)5) ||
line prediff period , lcolor(maroon) lpattern(dash) yline(0,lcolor(black)) ||
line postdiff period , lcolor(maroon) lpattern(dash)
ytitle("Difference in employment levels", axis(1) margin(r+2.0) size(large)) legend(off)
graphregion(color(white))
;
graph export Fig-toy_example_diff_tc.png , replace width(1000) ;

graph twoway bar diff_detrend period , barwidth(0.25) bcolor(gs12) xtitle("Time", size(large))
ylabel(-0.01(0.01)0.04) xline(0.5,lcolor(gs2)) xlabel(-5(1)5) ||
line dt_prediff period , lcolor(maroon) lpattern(dash) yline(0,lcolor(black)) ||
line dt_postdiff period , lcolor(maroon) lpattern(dash)
ytitle("Difference in employment levels", axis(1) margin(r+2.0) size(large)) legend(off)
graphregion(color(white))
;
graph export Fig-toy_example_diff_detrended.png , replace width(1000) ;

graph twoway bar diff_growth period , barwidth(0.25) bcolor(gs12) xtitle("Time" , size(large))
ylabel(-0.01(0.005)0.01) xline(0.5,lcolor(gs2)) xlabel(-5(1)5) ||
line prediff_growth period , lcolor(maroon) lpattern(dash) yline(0,lcolor(black)) ||
line postdiff_growth period , lcolor(maroon) lpattern(dash)
ytitle("Difference in employment growth", axis(1) margin(r+2.0) size(large)) legend(off)
graphregion(color(white))
;
graph export Fig-toy_example_diff_growth.png , replace width(1000) ;

graph twoway bar diff_dt_growth period , barwidth(0.25) bcolor(gs12) xtitle("Time", size(large))
ylabel(-0.01(0.005)0.01) xline(0.5,lcolor(gs2)) xlabel(-5(1)5) ||
line prediff_dt_growth period , lcolor(maroon) lpattern(dash) yline(0,lcolor(black)) ||
line postdiff_dt_growth period , lcolor(maroon) lpattern(dash)
ytitle("Difference in employment growth", axis(1) margin(r+2.0) size(large)) legend(off)
graphregion(color(white))
;
graph export Fig-toy_example_diff_dt_growth.png , replace width(1000) ;

#delimit cr

window manage close graph
clear all

****

* ILLUSTRATION OF STAGGERED TREATMENT

****

foreach case in 1 2 3 {

clear all
set obs 11
gen period = _n - 1 in 1/3
replace period = 2.999 in 4
replace period = _n - 2 in 5/7
replace period = 5.0001 in 8
replace period = _n - 3 in 9/11
label define period 3 "A treated (t{sub:1})" 5 "B treated (t{sub:2})" 8 "T"
label values period period

gen delta_treatment = (period >= 3 & period <= 5)


*local case = 3
* 1: no treatment effect
* 2: treatment effect on levels
* 3: treatment effect on growth rate


if `case' == 1 {  
gen empa = 1.5 + 0.2 * ceil(period)
replace empa = 1.5 + 0.2 * floor(period) if period > 3
gen empb = 0.7 + 0.2 * ceil(period)
replace empb = 0.7 + 0.2 * floor(period) if period > 3 
}

if `case' == 2 {
gen empa = 1.5 + 0.2 * ceil(period)
replace empa = 1.5 + 0.2 * floor(period) if period > 3
gen empb = 0.7 + 0.2 * ceil(period)
replace empb = 0.7 + 0.2 * floor(period) if period > 3 

replace empa = empa - 0.5 if period >= 3
replace empb = empb - 0.5 if period > 5 
}

if `case' == 3 {
gen empa = 1.5 + 0.2 * ceil(period)
replace empa = 1.5 + 0.2 * floor(period) if period > 3
gen empb = 0.7 + 0.2 * ceil(period)
replace empb = 0.7 + 0.2 * floor(period) if period > 3
 
replace empa = 2.1 + 0.05 * floor(period - 3) if period > 3
replace empb = 1.7 + 0.05 * floor(period - 5) if period > 5
}

gen diffemp = empa - empb
gen temp = diffemp if delta_treatment == 1
egen avgdiff_tr = mean(temp)
drop temp
gen temp = diffemp if delta_treatment == 0
egen avgdiff_not = mean(temp)
drop temp
gen diff_in_diff = round(avgdiff_tr - avgdiff_not , 0.00001)


#delimit ;
   line empa period if period >=0 & period < 3 , lcolor(gs8) lpattern(dash)
|| line empb period if period >=0 & period < 3  , lcolor(black) lpattern(solid)

|| line empa period if period >=  3 & period <= 5 , lcolor(gs8) lpattern(dash)
|| line empb period if period >=  3 & period <= 5  , lcolor(black) lpattern(solid)

|| line empa period if period >  5 & period <= 8 , lcolor(gs8) lpattern(dash)
|| line empb period if period >  5 & period <= 8  , lcolor(black) lpattern(solid)

xline(3 , lcolor(gs5) lpattern(dot)) 
xline(5 , lcolor(gs5) lpattern(dot))
ytitle("Employment level")
xtitle("Time") xlab(0 3 5 8 , valuelabels)
legend(rows(1) order(1 "Jurisdiction A" 2 "Jurisdiction B")) 
graphregion(color(white)) ylab(0) yscale(range(0 3.5))
;
#delimit cr


if `case' == 1 {
graph export Fig-staggered-example-no-effect.png , width(1000) replace
}

if `case' == 2 {
graph export Fig-staggered-example-level-effect.png , width(1000) replace
}

if `case' == 3 {
graph export Fig-staggered-example-growth-effect.png , width(1000) replace
}

}

window manage close graph
clear all
